@@ -65,7 +65,6 @@ class CoreModel(GObject.GObject):
     """
 
     __gsignals__ = {
-        "artists-loaded": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "playlist-loaded": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         "smart-playlist-change": (GObject.SignalFlags.RUN_FIRST, None, ())
     }
@@ -236,9 +235,6 @@ class CoreModel(GObject.GObject):
                 "state", player_song, "state",
                 GObject.BindingFlags.BIDIRECTIONAL
                 | GObject.BindingFlags.SYNC_CREATE)
-            player_song.bind_property(
-                "validation", model_song, "validation",
-                GObject.BindingFlags.SYNC_CREATE)
 
         def _on_items_changed(model, position, removed, added):
             songs_list = []
