@@ -24,12 +24,11 @@
 
 from gi.repository import GObject, Gtk
 
-from gnomemusic import log
 from gnomemusic.coreartist import CoreArtist
 
 
 @Gtk.Template(resource_path='/org/gnome/Music/ui/ArtistTile.ui')
-class ArtistTile(Gtk.EventBox):
+class ArtistTile(Gtk.ListBoxRow):
     """Row for sidebars
 
     Contains a label and an optional checkbox.
@@ -46,10 +45,6 @@ class ArtistTile(Gtk.EventBox):
     selection_mode = GObject.Property(type=bool, default=False)
     text = GObject.Property(type=str, default='')
 
-    def __repr__(self):
-        return '<ArtistTile>'
-
-    @log
     def __init__(self, coreartist=None):
         super().__init__()
 
