@@ -24,10 +24,8 @@
 
 from gi.repository import GObject, Gtk
 
-from gnomemusic import log
 
-
-@Gtk.Template(resource_path='/org/gnome/Music/SelectionToolbar.ui')
+@Gtk.Template(resource_path='/org/gnome/Music/ui/SelectionToolbar.ui')
 class SelectionToolbar(Gtk.ActionBar):
 
     __gtype_name__ = 'SelectionToolbar'
@@ -38,25 +36,22 @@ class SelectionToolbar(Gtk.ActionBar):
         'add-to-playlist': (GObject.SignalFlags.RUN_FIRST, None, ())
     }
 
-    items_selected = GObject.Property(type=int, default=0, minimum=0)
+    selected_items_count = GObject.Property(type=int, default=0, minimum=0)
 
-    def __repr__(self):
-        return '<SelectionToolbar>'
-
-    @log
     def __init__(self):
         super().__init__()
 
-        self.connect('notify::items-selected', self._on_item_selection_changed)
+        self.connect(
+            'notify::selected-items-count', self._on_item_selection_changed)
+
+        self.notify("selected-items-count")
 
     @Gtk.Template.Callback()
-    @log
     def _on_add_to_playlist_button_clicked(self, widget):
         self.emit('add-to-playlist')
 
-    @log
     def _on_item_selection_changed(self, widget, data):
-        if self.props.items_selected > 0:
+        if self.props.selected_items_count > 0:
             self._add_to_playlist_button.props.sensitive = True
         else:
             self._add_to_playlist_button.props.sensitive = False
